@@ -77,17 +77,22 @@ SEARCH_EXACT = {
     'google.ae': EngineDef('Google United Arab Emirates', 'q'),
     'google.af': EngineDef('Google Afghanistan', 'q'),
     'google.ag': EngineDef('Google Antiqua and Barbuda', 'q'),
+    'google.al': EngineDef('Google Albania', 'q'),
     'google.am': EngineDef('Google Armenia', 'q'),
     'google.as': EngineDef('Google American Samoa', 'q'),
     'google.at': EngineDef('Google Austria', 'q'),
     'google.az': EngineDef('Google Azerbaijan', 'q'),
     'google.ba': EngineDef('Google Bosnia and Herzegovina', 'q'),
     'google.be': EngineDef('Google Belgium', 'q'),
+    'google.bf': EngineDef('Google Burkina Faso', 'q'),
     'google.bg': EngineDef('Google Bulgaria', 'q'),
     'google.bi': EngineDef('Google Burundi', 'q'),
+    'google.bj': EngineDef('Google Benin', 'q'),
     'google.biz': EngineDef('Google dot biz', 'q'),
     'google.bo': EngineDef('Google Bolivia', 'q'),
     'google.bs': EngineDef('Google Bahamas', 'q'),
+    'google.bt': EngineDef('Google Bhutan', 'q'),
+    'google.by': EngineDef('Google Belarus', 'q'),
     'google.bz': EngineDef('Google Belize', 'q'),
     'google.ca': EngineDef('Google Canada', 'q'),
     'google.cc': EngineDef('Google Cocos Islands', 'q'),
@@ -96,7 +101,10 @@ SEARCH_EXACT = {
     'google.ch': EngineDef('Google Switzerland', 'q'),
     'google.ci': EngineDef('Google Cote dIvoire', 'q'),
     'google.cl': EngineDef('Google Chile', 'q'),
+    'google.cm': EngineDef('Google Cameroon', 'q'),
     'google.cn': EngineDef('Google China', 'q'),
+    'google.cv': EngineDef('Google Cape Verde', 'q'),
+    'google.co.ao': EngineDef('Google Angola', 'q'),
     'google.co.at': EngineDef('Google Austria', 'q'),
     'google.co.bi': EngineDef('Google Burundi', 'q'),
     'google.co.bw': EngineDef('Google Botswana', 'q'),
@@ -120,10 +128,12 @@ SEARCH_EXACT = {
     'google.co.ma': EngineDef('Google Morocco', 'q'),
     'google.co.mu': EngineDef('Google Mauritius', 'q'),
     'google.co.mw': EngineDef('Google Malawi', 'q'),
+    'google.co.mz': EngineDef('Google Mozambique', 'q'),
     'google.co.nz': EngineDef('Google New Zeland', 'q'),
     'google.co.pn': EngineDef('Google Pitcairn Islands', 'q'),
     'google.co.th': EngineDef('Google Thailand', 'q'),
     'google.co.tt': EngineDef('Google Trinidad and Tobago', 'q'),
+    'google.co.tz': EngineDef('Google Tanzania', 'q'),
     'google.co.ug': EngineDef('Google Uganda', 'q'),
     'google.co.uk': EngineDef('Google UK', 'q'),
     'google.co.uz': EngineDef('Google Uzbekistan', 'q'),
@@ -150,6 +160,7 @@ SEARCH_EXACT = {
     'google.com.cn': EngineDef('Google China', 'q'),
     'google.com.co': EngineDef('Google', 'q'),
     'google.com.cu': EngineDef('Google Cuba', 'q'),
+    'google.com.cy': EngineDef('Google Cyprus', 'q'),
     'google.com.do': EngineDef('Google Dominican Rep', 'q'),
     'google.com.ec': EngineDef('Google Ecuador', 'q'),
     'google.com.eg': EngineDef('Google Egypt', 'q'),
@@ -166,16 +177,19 @@ SEARCH_EXACT = {
     'google.com.hk': EngineDef('Google Hong Kong', 'q'),
     'google.com.hn': EngineDef('Google Honduras', 'q'),
     'google.com.hr': EngineDef('Google Croatia', 'q'),
+    'google.com.iq': EngineDef('Google Iraq', 'q'),
     'google.com.jm': EngineDef('Google Jamaica', 'q'),
     'google.com.jo': EngineDef('Google Jordan', 'q'),
     'google.com.kg': EngineDef('Google Kyrgyzstan', 'q'),
     'google.com.kh': EngineDef('Google Cambodia', 'q'),
     'google.com.ki': EngineDef('Google Kiribati', 'q'),
+    'google.com.kw': EngineDef('Google Kuwait', 'q'),
     'google.com.kz': EngineDef('Google Kazakhstan', 'q'),
     'google.com.lb': EngineDef('Google Lebanon', 'q'),
     'google.com.lk': EngineDef('Google Sri Lanka', 'q'),
     'google.com.lv': EngineDef('Google Latvia', 'q'),
     'google.com.ly': EngineDef('Google Libya', 'q'),
+    'google.com.mm': EngineDef('Google Myanmar', 'q'),
     'google.com.mt': EngineDef('Google Malta', 'q'),
     'google.com.mu': EngineDef('Google Mauritius', 'q'),
     'google.com.mw': EngineDef('Google Malawi', 'q'),
@@ -190,6 +204,7 @@ SEARCH_EXACT = {
     'google.com.om': EngineDef('Google Oman', 'q'),
     'google.com.pa': EngineDef('Google Panama', 'q'),
     'google.com.pe': EngineDef('Google Peru', 'q'),
+    'google.com.pg': EngineDef('Google PapuaNew Guinea', 'q'),
     'google.com.ph': EngineDef('Google Philipines', 'q'),
     'google.com.pk': EngineDef('Google Pakistan', 'q'),
     'google.com.pl': EngineDef('Google Poland', 'q'),
@@ -202,6 +217,7 @@ SEARCH_EXACT = {
     'google.com.sb': EngineDef('Google Solomon Islands', 'q'),
     'google.com.sc': EngineDef('Google Seychelles', 'q'),
     'google.com.sg': EngineDef('Google Singapore', 'q'),
+    'google.com.sl': EngineDef('Google Sierra Leone', 'q'),
     'google.com.sv': EngineDef('Google El Savador', 'q'),
     'google.com.tj': EngineDef('Google Tajikistan', 'q'),
     'google.com.tr': EngineDef('Google Turkey', 'q'),
@@ -210,6 +226,7 @@ SEARCH_EXACT = {
     'google.com.ua': EngineDef('Google Ukraine', 'q'),
     'google.com.uy': EngineDef('Google Uruguay', 'q'),
     'google.com.uz': EngineDef('Google Uzbekistan', 'q'),
+    'google.com.vc': EngineDef('Google Saint Vincent and the Grenadines', 'q'),
     'google.com.ve': EngineDef('Google Venezuela', 'q'),
     'google.com.vi': EngineDef('Google US Virgin Islands', 'q'),
     'google.com.vn': EngineDef('Google Vietnam', 'q'),
@@ -217,6 +234,7 @@ SEARCH_EXACT = {
     'google.cz': EngineDef('Google Czech Rep', 'q'),
     'google.de': EngineDef('Google Germany', 'q'),
     'google.dj': EngineDef('Google Djubouti', 'q'),
+    'google.dz': EngineDef('Google Algeria', 'q'),
     'google.dk': EngineDef('Google Denmark', 'q'),
     'google.dm': EngineDef('Google Dominica', 'q'),
     'google.ec': EngineDef('Google Ecuador', 'q'),
@@ -243,6 +261,7 @@ SEARCH_EXACT = {
     'google.im': EngineDef('Google Isle of Man', 'q'),
     'google.in': EngineDef('Google India', 'q'),
     'google.info': EngineDef('Google dot info', 'q'),
+    'google.iq': EngineDef('Google Iraq', 'q'),
     'google.is': EngineDef('Google Iceland', 'q'),
     'google.it': EngineDef('Google Italy', 'q'),
     'google.je': EngineDef('Google Jersey', 'q'),
@@ -260,6 +279,10 @@ SEARCH_EXACT = {
     'google.lv': EngineDef('Google Latvia', 'q'),
     'google.ma': EngineDef('Google Morocco', 'q'),
     'google.md': EngineDef('Google Moldova', 'q'),
+    'google.me': EngineDef('Google Montenegro', 'q'),
+    'google.mg': EngineDef('Google Madagascar', 'q'),
+    'google.mk': EngineDef('Google Macedonia', 'q'),
+    'google.ml': EngineDef('Google Mali', 'q'),
     'google.mn': EngineDef('Google Mongolia', 'q'),
     'google.mobi': EngineDef('Google dot mobi', 'q'),
     'google.ms': EngineDef('Google Montserrat', 'q'),
@@ -268,6 +291,7 @@ SEARCH_EXACT = {
     'google.mw': EngineDef('Google Malawi', 'q'),
     'google.net': EngineDef('Google dot net', 'q'),
     'google.nf': EngineDef('Google Norfolk Island', 'q'),
+    'google.ng': EngineDef('Google Nigeria', 'q'),
     'google.nl': EngineDef('Google Netherlands', 'q'),
     'google.no': EngineDef('Google Norway', 'q'),
     'google.nr': EngineDef('Google Nauru', 'q'),
@@ -278,6 +302,7 @@ SEARCH_EXACT = {
     'google.pl': EngineDef('Google Poland', 'q'),
     'google.pn': EngineDef('Google Pitcairn Islands', 'q'),
     'google.pr': EngineDef('Google Puerto Rico', 'q'),
+    'google.ps': EngineDef('Google Palestine', 'q'),
     'google.pt': EngineDef('Google Portugal', 'q'),
     'google.ro': EngineDef('Google Romania', 'q'),
     'google.rs': EngineDef('Google Serbia', 'q'),
@@ -291,10 +316,15 @@ SEARCH_EXACT = {
     'google.sk': EngineDef('Google Slovakia', 'q'),
     'google.sm': EngineDef('Google San Marino', 'q'),
     'google.sn': EngineDef('Google Senegal', 'q'),
+    'google.so': EngineDef('Google Somalia', 'q'),
     'google.sr': EngineDef('Google Suriname', 'q'),
     'google.st': EngineDef('Google Sao Tome', 'q'),
+    'google.td': EngineDef('Google Chad', 'q'),
+    'google.tg': EngineDef('Google Togo', 'q'),
     'google.tk': EngineDef('Google Tokelau', 'q'),
+    'google.tl': EngineDef('Google East Timor', 'q'),
     'google.tm': EngineDef('Google Turkmenistan', 'q'),
+    'google.tn': EngineDef('Google Tunisia', 'q'),
     'google.to': EngineDef('Google Tonga', 'q'),
     'google.tp': EngineDef('Google East Timor', 'q'),
     'google.tt': EngineDef('Google Trinidad and Tobago', 'q'),
